@@ -9,7 +9,7 @@ class ECRCodePipelineStack(Stack):
     '''
     This Stack Creates a CodePipeline that Updates ECR Images when a given CodeCommit Repository is Updated
     '''
-    def __init__(self, scope: Construct, construct_id: str, codecommit_repository_name: str, codecommit_repository_branch: str, codebuild_action_name: str, codebuild_role_arn: permission.iam.Role.role_arn, codepipeline_name: str, codecommit_initial_commit_dir: str, ecr_repository_name: str, ecr_repository_tag: str, ecr_account_id: str, ecr_account_region: str,  **kwargs) -> None:
+    def __init__(self, scope: Construct, construct_id: str, codecommit_repository_name: str, codecommit_repository_branch: str, codebuild_action_name: str, codebuild_role_arn: permission.iam.Role.role_arn, codepipeline_name: str, codepipeline_role_arn: permission.iam.Role.role_arn, codecommit_initial_commit_dir: str, ecr_repository_name: str, ecr_repository_tag: str, ecr_account_id: str, ecr_account_region: str,  **kwargs) -> None:
         super().__init__(scope, construct_id, **kwargs)
     
         ## 
@@ -66,7 +66,7 @@ class ECRCodePipelineStack(Stack):
         ################################
 
         # Create CodePipeline
-        codepipeline = cicd.createCodePipeline(self, codepipeline_name, codecommit_source_action, codebuild_build_action, deploy_action=None)
+        codepipeline = cicd.createCodePipeline(self, codepipeline_name, codepipeline_role_arn, codecommit_source_action, codebuild_build_action, deploy_action=None)
 
 
         
\ No newline at end of file
